@@ -54,6 +54,18 @@ from teslajsonpy.homeassistant.trunk import FrunkLock, TrunkLock
 from teslajsonpy.homeassistant.heated_steering_wheel import HeatedSteeringWheelSwitch
 from teslajsonpy.homeassistant.power import PowerSensor
 from teslajsonpy.homeassistant.alerts import Horn, FlashLights
+from teslajsonpy.homeassistant.homelink import TriggerHomelink
+from teslajsonpy.homeassistant.vehicle_data import (
+    ChargeStateDataSensor,
+    ClimateStateDataSensor,
+    DriveStateDataSensor,
+    GuiSettingsDataSensor,
+    SoftwareDataSensor,
+    SpeedLimitDataSensor,
+    VehicleConfigDataSensor,
+    VehicleDataSensor,
+    VehicleStateDataSensor,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -73,7 +85,7 @@ def min_expo(base=2, factor=1, max_value=None, min_value=0):
     """
     n = 0
     while True:
-        a = min_value + factor * base ** n
+        a = min_value + factor * base**n
         if max_value is None or a < max_value:
             yield a
             n += 1
@@ -724,6 +736,18 @@ class Controller:
         self.__components.append(HeatedSteeringWheelSwitch(car, self))
         self.__components.append(Horn(car, self))
         self.__components.append(FlashLights(car, self))
+        self.__components.append(TriggerHomelink(car, self))
+        self.__components.append(ChargeStateDataSensor(car, self))
+        self.__components.append(ClimateStateDataSensor(car, self))
+        self.__components.append(DriveStateDataSensor(car, self))
+        self.__components.append(GuiSettingsDataSensor(car, self))
+        self.__components.append(SoftwareDataSensor(car, self))
+        self.__components.append(SpeedLimitDataSensor(car, self))
+        self.__components.append(VehicleConfigDataSensor(car, self))
+        self.__components.append(VehicleDataSensor(car, self))
+        self.__components.append(VehicleStateDataSensor(car, self))
+        self.__components.append(ChargeStateDataSensor(car, self))
+
         for seat in ["left", "right", "rear_left", "rear_center", "rear_right"]:
             try:
                 self.__components.append(HeatedSeatSelect(car, self, seat))
@@ -774,7 +798,9 @@ class Controller:
                 vin=vin, timestamp=cur_time, shift_state=self.shift_state(vin=vin)
             )
         if self.is_in_gear(vin=vin):
-            driving_interval = min(DRIVING_INTERVAL, self.get_update_interval_vin(vin=vin))
+            driving_interval = min(
+                DRIVING_INTERVAL, self.get_update_interval_vin(vin=vin)
+            )
             if self.__update_state[vin] != "driving":
                 self.__update_state[vin] = "driving"
                 _LOGGER.debug(
@@ -977,7 +1003,7 @@ class Controller:
                         )
                         and (  # pylint: disable=too-many-boolean-expressions
                             self.__update.get(vin)
-                        )
+                        )  # Only update cars with update flag on
                         and (
                             force
                             or vin not in self._last_update_time
@@ -986,13 +1012,18 @@ class Controller:
                                 >= self._calculate_next_interval(vin)
                             )
                         )
-                    ):  # Only update cars with update flag on
+                    ):
                         tasks.append(_get_and_process_car_data(vin))
                     else:
                         _LOGGER.debug(
-                            "%s: Skipping update with state %s. Last update: %s ago. Last parked: %s ago. Last wake_up %s ago",
+                            (
+                                "%s: Skipping update with state %s. Polling: %s. "
+                                "Last update: %s ago. Last parked: %s ago. "
+                                "Last wake_up %s ago. "
+                            ),
                             vin[-5:],
                             car_state,
+                            self.__update.get(vin),
                             cur_time - self._last_update_time[vin],
                             cur_time - self.get_last_park_time(vin=vin),
                             cur_time - self.get_last_wake_up_time(vin=vin),
@@ -1313,6 +1344,8 @@ class Controller:
     ) -> None:
         """Set updates dictionary.
 
+        If a vehicle is enabled, the vehicle will force an update on next poll.
+
         Parameters
         ----------
         car_id : string
@@ -1334,6 +1367,12 @@ class Controller:
             vin = self._id_to_vin(car_id)
         if vin:
             self.__update[vin] = value
+            if self.__update[vin]:
+                self.set_last_update_time(vin=vin)
+                _LOGGER.debug(
+                    "%s: Set Updates enabled; forcing update on next poll by resetting last_update_time",
+                    vin[-5:],
+                )
 
     def get_last_update_time(self, car_id: Text = None, vin: Text = None):
         """Get last_update time dictionary.
@@ -1548,7 +1587,9 @@ class Controller:
             _LOGGER.debug("Update interval set to %s.", value)
             self._update_interval = int(value)
 
-    def set_update_interval_vin(self, car_id: Text = None, vin: Text = None, value: int = None) -> None:
+    def set_update_interval_vin(
+        self, car_id: Text = None, vin: Text = None, value: int = None
+    ) -> None:
         """Set update interval for specific vin."""
 
         if car_id and not vin:
